@@ -13,18 +13,18 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import abc
-import json
 
-import six
-from six.moves.urllib import parse
+import abc
+
 from stevedore import extension
+from urllib import parse
+
+from oslo_serialization import jsonutils
 
 from designateclient import exceptions
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Controller(object):
+class Controller(object, metaclass=abc.ABCMeta):
 
     def __init__(self, client):
         self.client = client
@@ -44,8 +44,11 @@ class Controller(object):
         }
 
     def _serialize(self, kwargs):
-        if 'data' in kwargs:
-            kwargs['data'] = json.dumps(kwargs['data'])
+        headers = kwargs.get('headers')
+        content_type = headers.get('Content-Type') if headers else None
+
+        if 'data' in kwargs and content_type in {None, 'application/json'}:
+            kwargs['data'] = jsonutils.dumps(kwargs['data'])
 
     def _post(self, url, response_key=None, **kwargs):
         self._serialize(kwargs)
@@ -77,12 +80,14 @@ class Controller(object):
             return body[response_key]
         return body
 
-    def _delete(self, url):
-        resp, body = self.client.session.delete(url)
+    def _delete(self, url, response_key=None, **kwargs):
+        resp, body = self.client.session.delete(url, **kwargs)
+        if response_key is not None:
+            return body[response_key]
+        return body
 
 
-@six.add_metaclass(abc.ABCMeta)
-class CrudController(Controller):
+class CrudController(Controller, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def list(self, *args, **kw):
@@ -93,7 +98,7 @@ class CrudController(Controller):
     @abc.abstractmethod
     def get(self, *args, **kw):
         """
-        Get a resouce
+        Get a resource
         """
 
     @abc.abstractmethod
@@ -124,6 +129,6 @@ def Client(version, *args, **kwargs):  # noqa
     versions = get_versions()
     if version not in versions:
         msg = 'Version %s is not supported, use one of (%s)' % (
-            version, list(six.iterkeys(versions)))
+            version, list(versions.keys()))
         raise exceptions.UnsupportedVersion(msg)
     return versions[version](*args, **kwargs)
